if (app.documents.length > 0 && app.activeDocument.selection.length > 0) {
  var doc = app.activeDocument;
  var sel = doc.selection;

  function splitByCharType(text) {
    var blocks = [];
    var buffer = "";
    var lastType = null;

    function getCharType(ch) {
      if (/[a-zA-Z0-9]/.test(ch)) return "latin";
      if (/[぀-ゟ]/.test(ch)) return "hiragana";
      if (/[゠-ヿ]/.test(ch)) return "katakana";
      if (/[一-鿿]/.test(ch)) return "kanji";
      if (/\s/.test(ch)) return "space";
      return "other";
    }

    for (var i = 0; i < text.length; i++) {
      var ch = text[i];
      var type = getCharType(ch);

      if (type === "space") {
        if (buffer !== "") {
          blocks.push(buffer);
          buffer = "";
        }
        continue;
      }

      if (type !== lastType && buffer !== "") {
        blocks.push(buffer);
        buffer = ch;
      } else {
        buffer += ch;
      }

      lastType = type;
    }

    if (buffer !== "") {
      blocks.push(buffer);
    }

    return blocks;
  }

  for (var i = 0; i < sel.length; i++) {
    var item = sel[i];
    if (item.typename === "TextFrame" && item.kind === TextType.POINTTEXT) {
      var blocks = splitByCharType(item.contents);
      var originalPos = item.position;
      var orientation = item.orientation;
      var attr = item.textRange.characterAttributes;
      var fontSize = attr.size;

      var spacingX = fontSize * 0.6;
      var spacingY = fontSize * 2.0;
      var createdTexts = [];

      var cursorX = originalPos[0];
      var cursorY = originalPos[1];

      for (var j = 0; j < blocks.length; j++) {
        var newText = doc.textFrames.pointText([cursorX, cursorY]);
        newText.contents = blocks[j];
        newText.orientation = orientation;

        var newAttr = newText.textRange.characterAttributes;
        newAttr.size = attr.size;
        newAttr.textFont = attr.textFont;
        newAttr.fillColor = attr.fillColor;
        newAttr.tracking = attr.tracking;
        newAttr.baselineShift = attr.baselineShift;

        app.redraw();

        if (orientation === TextOrientation.HORIZONTAL) {
          var width = newText.width;
          cursorX += width + spacingX;
        } else {
          cursorY -= spacingY;
        }

        createdTexts.push(newText);
        $.sleep(1);
      }

      item.remove();

      // 横組み：初期位置に最初の語を戻す
      if (orientation === TextOrientation.HORIZONTAL && createdTexts.length > 1) {
        var leftText = createdTexts[0];
        var deltaX = originalPos[0] - leftText.position[0];
        var deltaY = originalPos[1] - leftText.position[1];

        for (var a = 0; a < createdTexts.length; a++) {
          var p = createdTexts[a].position;
          createdTexts[a].position = [p[0] + deltaX, p[1] + deltaY];
        }
      }

      // 縦組み：基点復元＋キー化＋案内＋全選択
      if (orientation === TextOrientation.VERTICAL && createdTexts.length > 1) {
        var topText = createdTexts[0];
        var deltaX = originalPos[0] - topText.position[0];
        var deltaY = originalPos[1] - topText.position[1];

        for (var k = 0; k < createdTexts.length; k++) {
          var p = createdTexts[k].position;
          createdTexts[k].position = [p[0] + deltaX, p[1] + deltaY];
        }

        // 最上語をキー化（cut → pasteFront）
        app.selection = null;
        topText.selected = true;
        app.cut();
        app.executeMenuCommand("pasteFront");

        if (app.selection.length === 1 && app.selection[0].typename === "TextFrame") {
          createdTexts[0] = app.selection[0];
        }

        // 全部再選択
        app.selection = null;
        for (var m = 0; m < createdTexts.length; m++) {
          createdTexts[m].selected = true;
        }

        var msg = "処理の後で「整列」パネルを表示して以下のステップ。\n\n" +
                  "1.整列の右：「キーオブジェクトに整列」ボタン\n" +
                  "2.等間隔に分布の：語の隙間のmmの入力\n" +
                  "3.等間隔に分布の左：「垂直に均等分布」ボタン\n";
        alert(msg);
      }
    }
  }

  alert("語を分割しました。");
} else {
  alert("ポイントテキストを選択してください。");
}
